(v1.3.6)=
### 1.3.6 {small}`2018-12-11`

#### Major updates

- a new plotting gallery for `visualizing-marker-genes` {smaller}`F Ramirez`
- tutorials are integrated on ReadTheDocs, `pbmc3k` and `paga-paul15` {smaller}`A Wolf`

#### Interactive exploration of analysis results through *manifold viewers*

- CZI’s [cellxgene] directly reads `.h5ad` files {smaller}`the cellxgene developers`
- the [UCSC Single Cell Browser] requires exporting via {func}`~scanpy.external.exporting.cellbrowser` {smaller}`M Haeussler`

#### Code design

- {func}`~scanpy.pp.highly_variable_genes` supersedes {func}`~scanpy.pp.filter_genes_dispersion`, it gives the same results but, by default, expects logarithmized data and doesn’t subset {smaller}`A Wolf`

[cellxgene]: https://github.com/chanzuckerberg/cellxgene
[ucsc single cell browser]: https://github.com/maximilianh/cellBrowser
